%bcond_without     tests

%undefine _strict_symbol_defs_build

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name  15-xdebug.ini

Summary:        Provides functions for function traces and profiling
Name:           php-pecl-xdebug3
Version:        3.3.2
Release:        1%{?dist}
License:        PHP-3.01
URL:            https://xdebug.org/
Source0:        https://github.com/xdebug/xdebug/archive/%{version}/xdebug-%{version}.tar.gz

BuildRequires:  gcc, make, php-devel, php-pear, php-simplexml, libtool, php-soap

Requires:       php-common

Provides:       php-xdebug                = %{version}
Provides:       php-xdebug%{?_isa}        = %{version}
Provides:       php-pecl(Xdebug)          = %{version}
Provides:       php-pecl(Xdebug)%{?_isa}  = %{version}
Provides:       php-pecl-xdebug           = %{version}-%{release}
Provides:       php-pecl-xdebug%{?_isa}   = %{version}-%{release}

%description
The Xdebug extension helps you debugging your script by providing a lot of
valuable debug information. The debug information that Xdebug can provide
includes the following:

* stack and function traces in error messages with:
  o full parameter display for user defined functions
  o function name, file name and line indications
  o support for member functions
* memory allocation
* protection for infinite recursions

Xdebug also provides:

* profiling information for PHP scripts
* code coverage analysis
* capabilities to debug your scripts interactively with a debug client

Documentation: https://xdebug.org/docs/



%prep
%setup -qc
mv xdebug-%{version} NTS
mv NTS/package.xml .

sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml

cd NTS
ver=$(sed -n '/XDEBUG_VERSION/{s/.* "//;s/".*$//;p}' php_xdebug.h)
if test "$ver" != "%{version}"; then
   : Error: Upstream XDEBUG_VERSION version is ${ver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
cp -pr NTS ZTS
%endif

cat << 'EOF' | tee %{ini_name}
; Enable xdebug extension module
zend_extension=xdebug.so

; Configuration
; See https://xdebug.org/docs/all_settings

EOF
sed -e '1d' NTS/xdebug.ini >>%{ini_name}



%build
cd NTS
%{_bindir}/phpize
%configure \
    --enable-xdebug  \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --enable-xdebug  \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif



%install
make -C NTS install INSTALL_ROOT=%{buildroot}

install -Dpm 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

install -Dpm 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -Dpm 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do
  [ -f NTS/contrib/$i ] && j=contrib/$i || j=$i
  install -Dpm 644 NTS/$j %{buildroot}%{pecl_docdir}/xdebug/$j
done



%check
modules=""
for mod in simplexml; do
  if [ -f %{php_extdir}/${mod}.so ]; then
    modules="$modules -d extension=${mod}.so"
  fi
done

%{_bindir}/php \
    --no-php-ini \
    --define zend_extension=%{buildroot}%{php_extdir}/xdebug.so \
    --modules | grep Xdebug

%if %{with_zts}
%{_bindir}/zts-php \
    --no-php-ini \
    --define zend_extension=%{buildroot}%{php_ztsextdir}/xdebug.so \
    --modules | grep Xdebug
%endif

%if %{with tests}
cd NTS
: Upstream test suite NTS extension

rm tests/base/bug02036.phpt
rm tests/debugger/bug00998-ipv6.phpt

TEST_OPTS="-q -x --show-diff"

TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="-n $modules -d zend_extension=%{buildroot}%{php_extdir}/xdebug.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-xdebug-tests.php $TEST_OPTS
%else
: Test suite disabled
%endif



%files
%license NTS/LICENSE
%doc %{pecl_docdir}/xdebug
%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/xdebug.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/xdebug.so
%endif



%changelog
* Wed Nov 27 2024 Zhongze Hu <joshuahu@tencent.com> - 3.3.2-1
- [Type] Update 
- [DESC] Update to upstream 3.3.2

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.2-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.2-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Sep 04 2023 Miaojun Dong <zoedong@tencent.com> - 3.2.2-1
- Bump version to 3.2.2

* Fri Sep 01 2023 Miaojun Dong <zoedong@tencent.com> - 3.2.0-4
- Rebuild for php-8.2.9

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.0-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Jan 9 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.2.0-1
- initial
